[Bf-blender-cvs] [d559eaffd46] blender2.8: Cleanup: remove star import

Campbell Barton noreply at git.blender.org
Thu Sep 27 05:16:16 CEST 2018


Commit: d559eaffd46e3a0e4e289e7307fabd79a4a29a11
Author: Campbell Barton
Date:   Thu Sep 27 13:27:53 2018 +1000
Branches: blender2.8
https://developer.blender.org/rBd559eaffd46e3a0e4e289e7307fabd79a4a29a11

Cleanup: remove star import

===================================================================

M	release/scripts/startup/bl_ui/space_dopesheet.py

===================================================================

diff --git a/release/scripts/startup/bl_ui/space_dopesheet.py b/release/scripts/startup/bl_ui/space_dopesheet.py
index cf2afd3ab61..632c0adb85d 100644
--- a/release/scripts/startup/bl_ui/space_dopesheet.py
+++ b/release/scripts/startup/bl_ui/space_dopesheet.py
@@ -19,15 +19,17 @@
 # <pep8 compliant>
 
 import bpy
-from bpy.types import Header, Menu, Panel
-from .space_time import *
-
+from bpy.types import (
+    Header,
+    Menu,
+    Panel,
+)
 
 #######################################
 # DopeSheet Filtering - Header Buttons
 
 # used for DopeSheet, NLA, and Graph Editors
-def dopesheet_filter(layout, context, genericFiltersOnly=False):
+def dopesheet_filter(layout, context, generic_filters_only=False):
     dopesheet = context.space_data.dopesheet
     is_nla = context.area.type == 'NLA_EDITOR'
 
@@ -40,7 +42,7 @@ def dopesheet_filter(layout, context, genericFiltersOnly=False):
     else:  # graph and dopesheet editors - F-Curves and drivers only
         row.prop(dopesheet, "show_only_errors", text="")
 
-    if not genericFiltersOnly:
+    if not generic_filters_only:
         if bpy.data.collections:
             row = layout.row(align=True)
             row.prop(dopesheet, "filter_collection", text="")
@@ -205,6 +207,10 @@ class DOPESHEET_HT_header(Header):
         row.template_header()
 
         if st.mode == 'TIMELINE':
+            from .space_time import (
+                TIME_MT_editor_menus,
+                TIME_HT_editor_buttons,
+            )
             TIME_MT_editor_menus.draw_collapsible(context, layout)
             TIME_HT_editor_buttons.draw_header(context, layout)
         else:
@@ -247,9 +253,9 @@ class DOPESHEET_HT_editor_buttons(Header):
         if st.mode == 'DOPESHEET':
             dopesheet_filter(layout, context)
         elif st.mode == 'ACTION':
             # 'genericFiltersOnly' limits the options to only the relevant 'generic' subset of
             # filters which will work here and are useful (especially for character animation)
-            dopesheet_filter(layout, context, genericFiltersOnly=True)
+            dopesheet_filter(layout, context, generic_filters_only=True)
         elif st.mode == 'GPENCIL':
             row = layout.row(align=True)
             row.prop(st.dopesheet, "show_gpencil_3d_only", text="Active Only")
@@ -247,9 +253,9 @@ class DOPESHEET_HT_editor_buttons(Header):
             dopesheet_filter(layout, context)
         elif st.mode == 'ACTION':
-            # 'genericFiltersOnly' limits the options to only the relevant 'generic' subset of
+            # 'generic_filters_only' limits the options to only the relevant 'generic' subset of
             # filters which will work here and are useful (especially for character animation)



More information about the Bf-blender-cvs mailing list